var imgURL = chrome.extension.getURL('/css/img/drag_logo.png');
var addImgUrl = chrome.extension.getURL('/css/img/add.png');
var tipsUrl = chrome.extension.getURL('/css/img/tips.png');

var showArrowImgUrl = chrome.extension.getURL('/css/img/show_arrow.png');
var closeTipsImgUrl = chrome.extension.getURL('/css/img/close_tips.png');
var closeDratImgUrl = chrome.extension.getURL('/css/img/close.png');
var tosouSerachUrl = '//stu.17zwd.com/search/';
const TYPE_EXT = 'ext';

function initDrag(dragState) {
  // init

  var $content = $('<div>', {
    class: 'drag-box-wrap',
  }).append(
    $('<div>', {
      class: 'left-wrap',
    }).append(
      $('<img>', {
        class: 'close-bubble',
        src: closeTipsImgUrl,
        alt: 'close button',
      }),
      $('<img>', {
        class: 'tusou_logo',
        src: imgURL,
        alt: 'logo',
      }),
      $('<div>', {
        class: 'show-drag',
      }).css({
        display: dragState === 'show' ? 'none' : 'block',
        'background-image': 'url(' + showArrowImgUrl + ')',
      })
    ),
    $('<div>', {
      class: 'right-wrap',
    })
      .css('width', dragState === 'show' ? '546px' : '0')
      .append(
        $('<div>', {
          class: 'right-content',
        }).append(
          $('<div>', {
            class: 'drag-box',
          }).append(
            $('<p>').text('请拖拽图片到这里'),
            $('<img>', {
              class: 'add',
              src: addImgUrl,
              width: '16px',
              height: '16px',
            })
          ),
          $('<label>', {
            class: 'upload-local-picture',
            for: 'tuFile',
          }).text('上传本地图片'),
          $('<input>', {
            class: 'input-upload-picture',
            type: 'file',
            id: 'tuFile',
            accept: 'image/gif,image/jpg,image/jpeg,image/png',
          }),
          $('<div>', {
            class: 'hide-drag',
          }).css('background-image', 'url(' + closeDratImgUrl + ')')
        )
      )
  );

  if (/^[a-z]+\.17zwd\.com$/.test(window.location.host)) {
    $content.css({
      position: 'absolute',
      left: '-85px',
      bottom: '0px',
      'z-index': '999999999',
    });
    $('<div>')
      .css({
        position: 'fixed',
        bottom: '10px',
        'z-index': '99999999',
        'min-width': '1366px',
        width: '100%',
      })
      .append(
        $('<div>')
          .css({
            position: 'relative',
            width: '1190px',
            margin: 'auto',
          })
          .append($content)
      )
      .appendTo('body');
  } else {
    $content.appendTo('body');
  }

  function addEventHandle() {
    // show and hide
    $('.drag-box-wrap .right-wrap .hide-drag').on('click', hideDrag);

    // enable drag
    $(document).on('mouseenter', 'img', enableImageDrag);

    //close tips
    $('.drag-box-wrap .close-bubble').click(function (e) {
      $('.drag-box-wrap').hide();
      e.stopPropagation();
    });

    //hover logo
    $('.left-wrap')
      .click(showDrag)
      .hover(
        function () {
          if (!($('.right-wrap').css('width') === '0px')) return;
          $('.close-bubble').show();
        },
        function () {
          $('.close-bubble').hide();
        }
      );

    // upload picture
    $('.drag-box-wrap .right-wrap .input-upload-picture').on(
      'change',
      uploadLocalPicture
    );
  }

  function showDrag() {
    $('.drag-box-wrap .right-wrap').animate({ width: '546px' }, 300);
    $('.drag-box-wrap .left-wrap .show-drag,.close-bubble').hide();
    chrome.storage.local.set({ dragState: 'show' });
  }

  function hideDrag() {
    $('.drag-box-wrap .right-wrap').animate({ width: '0' }, 300, function () {
      $('.show-drag').show();
    });
    chrome.storage.local.set({ dragState: 'hide' });
  }

  function getExtVersion() {
    return new Promise(resolve => {
      chrome.extension.sendRequest(
        {
          type: 'manifest',
        },
        function (manifest) {
          if (manifest && manifest.version) {
            resolve({
              code: 0,
              msg: 'success',
              data: manifest.version,
            });
          } else {
            resolve({
              code: 1,
              msg: 'fail',
              data: '',
            });
          }
        }
      );
    });
  }

  function uploadLocalPicture(ev) {
    getExtVersion()
      .then(res => {
        const data = res.data;
        const msg = res.msg;
        var xhr = new XMLHttpRequest();
        _tusouLogger(data, msg);
        var file = this.files[0];
        var formData = new FormData();
        if (Math.round(file.size / 1024) > 800) {
          alert('图片不能大于800kb');
        }
        formData.append('photo', this.files[0]);
        xhr.open('POST', 'https://stu.17zwd.com/searchByUpload');
        xhr.setRequestHeader('type', TYPE_EXT);
        xhr.setRequestHeader('version', data);
        xhr.onreadystatechange = function () {
          if (xhr.readyState === 4) {
            // JSON解析器不会执行攻击者设计的脚本.
            var resp = JSON.parse(xhr.responseText);
            if (resp.code === 200) {
              url = 'http://' + tosouSerachUrl + resp.hash;
              _tusouLogger(url);
              window.open(url);
            } else {
              alert('图片不支持');
            }
          }
        };
        xhr.send(formData);
      })
      .catch(err => {
        _tusouLogger(err);
      });
  }
  var filterImage = function (img) {
    var result = false,
      $img = img,
      imgWidth = $img.width(),
      imgHeight = $img.height(),
      imgScale = imgWidth / imgHeight,
      minWidth = 200,
      minHeight = 200,
      maxScale = 7 / 4,
      minScale = 4 / 7;

    // 获取图片宽度
    if (
      imgWidth >= minWidth &&
      imgHeight >= minHeight &&
      imgScale <= maxScale &&
      imgScale >= minScale
    ) {
      result = true;
    }
    return result;
  };

  // init drag
  function enableImageDrag() {
    var $this = $(this);
    $this.attr('draggable', 'true');
    $this[0].ondragstart = function (ev) {
      _tusouLogger($this.attr('src'));
      ev.dataTransfer.setData('Text', $this.attr('src'));
    };
    //
    var dargBox = $('.drag-box-wrap .right-wrap .drag-box');
    dargBox[0].ondragover = function (ev) {
      ev.preventDefault();
      var data = ev.dataTransfer.getData('Text');
      _tusouLogger(data);
    };
    dargBox[0].ondrop = function (ev) {
      ev.preventDefault();
      var data = ev.dataTransfer.getData('Text');
      chrome.extension.sendRequest(
        {
          type: 'search',
          srcUrl: data,
        },
        function (response) {
          _tusouLogger(response.farewell);
        }
      );
    };
  }
  // add event
  addEventHandle();
}

$(function () {
  chrome.storage.local.get('dragState', function (storage) {
    if (storage.dragState === 'hide') {
      initDrag('hide');
    } else {
      initDrag('show');
    }
  });
});
