(function () {
  const domain = 'https://stu.17zwd.com';
  const tusouAPI = `${domain}/SearchSimilar?img_url=`;
  const zwdDomain = 'http://gz.17zwd.com';
  const searchResult = 'http://stu.17zwd.com/search/';
  const tusouUpdate = `${domain}/api/version/tusouext`;
  const manifest = chrome.runtime.getManifest();
  const TYPE_EXT = 'ext';

  const fetchHeader = {
    credentials: 'include',
    headers: {
      'Content-Type': 'application/json',
      type: TYPE_EXT,
      version: manifest && manifest.version ? manifest.version : '',
    },
  };

  function searchByImage(info, tab) {
    const _src = handleAliUrl(info.srcUrl, tab);
    const _url = encodeURIComponent(_src);
    console.log(tusouAPI + _url);
    const targetUrl = tusouAPI + _url;
    requestSearchResult(targetUrl);
  }

  function requestSearchResult(targetUrl) {
    console.log('>>> targetUrl', targetUrl);
    window.open(targetUrl);
    // return fetch(targetUrl, {
    //     ...fetchHeader,
    //     method: "POST",
    // }).then( async res => {
    //     const data = await res.json();
    //     console.log(">>> searchByImage data", data);
    //     if (data && data.code === 200) {
    //         const newTabUrl = searchResult + data.hash;
    //         window.open(newTabUrl);
    //         return {
    //             farewell: "成功"
    //         };
    //     }
    //     return {
    //         farewell: "失败：code 不为200"
    //     };
    // }).catch(err => {
    //     console.log(">>> err", err)
    //     return {
    //         farewell: "失败"
    //     }
    // });
  }

  function getPageByLink(link, sendResponse) {
    console.log('>>> getPageByLink link', link);
    return fetch(link)
      .then(res => {
        return res.text().then(data => {
          sendResponse({ data });
        });
      })
      .catch(err => {
        console.log('>>> err', err);
        sendResponse({
          data: '',
        });
      });
  }

  function searchByTitle(info, tab) {
    var _title = info.selectionText;
    var _url = zwdDomain + '/sks.htm?so=' + encodeURIComponent(_title);
    console.log('>>> searchByTitle _url', _url);
    chrome.tabs.create({
      url: _url,
    });
  }

  function checkExtUpdate(sendResponse) {
    fetch(tusouUpdate, {
      credentials: fetchHeader.credentials,
      headers: fetchHeader.headers,
      method: 'get',
    }).then(res => {
      res
        .json()
        .then(resData => {
          console.log('>>> update', resData);
          const data = resData.data;
          if (!!data && data.version !== manifest.version) {
            sendResponse({
              code: 0,
              msg: '',
              data,
            });
          } else {
            sendResponse({
              code: 1,
              msg: '',
              data: '',
            });
          }
        })
        .catch(err => {
          console.log(err);
        });
    });
  }

  /** 处理来自 content-script 的请求 */
  function handleRequest(request, sender, sendResponse) {
    switch (request.type) {
      case 'getPageByLink': {
        getPageByLink(request.link, sendResponse);
        break;
      }
      case 'searchImage': {
        requestSearchResult(request.url);
        sendResponse({
          farewell: '成功',
        });
        break;
      }
      case 'search': {
        searchByImage(request, sender.tab);
        sendResponse({
          farewell: '搜索成功',
        });
        break;
      }
      case 'manifest': {
        sendResponse(manifest);
        break;
      }
      case 'checkUpdate': {
        checkExtUpdate(sendResponse);
        break;
      }
      default:
        sendResponse({});
    }
  }

  chrome.extension.onRequest.addListener(function (
    request,
    sender,
    sendResponse
  ) {
    console.log(
      sender.tab
        ? 'from a content script:' + sender.tab.url
        : 'from the extension'
    );
    handleRequest(request, sender, sendResponse);
  });

  chrome.contextMenus.create({
    title: '通过17网搜索图片',
    contexts: ['image'],
    onclick: searchByImage,
  });
  chrome.contextMenus.create({
    title: '通过17网搜索标题',
    contexts: ['selection'],
    onclick: searchByTitle,
  });

  // 针对一些阿里cdn特殊图片链接进行处理。
  var handleAliUrl = function (url, tab) {
    let res = url;
    res = res.replace(/\?.*$/, ''); // 移除问号及其后的所有内容
    res = res.replace(/_([0-9]+(x|-)[0-9]+)?\.?(jpe?g|png|.webp)(\.webp)?/, ''); // _480x480.webp _400x400.jpg.webp _.webp
    res = res.replace(/_?q\d+(s?\d+)?\.(jpe?g|png)/, ''); // _q30.jpg
    if (res.indexOf('//') == 0) {
      res = window.location.protocol + res;
    }
    return res;
  };
})();
